profiles

package
v0.0.0-...-b4d8713 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 20, 2017 License: Apache-2.0 Imports: 4 Imported by: 0

README

Profiles

A profile is a unique representation of a cluster. Think of these as handy snippets of Go that represent a cluster. Ideally you can pass these around from dev to dev, and tweak them to your liking.

It is important to note that a profile comes with no guarantee (by design). So it will be up to you to make sure your profile works! But don't worry, the core of kubicorn will help make that easy.

Profiles are struct{} literals in Go (by design). So you should always be able to define it just as easy as a configuration file. So no need for YAML abstractions before hand!

Why are there so many?

Because there are a lot of different combinations of cluster resources a user might want.

Can I add one to the repo?

Yep. Check out contributing for more information!

Can I host my own?

Yep. We have a feature coming soon that will allow you to point to local disk or a remote resource!

Is it Go or YAML?

Go. Then it turns into YAML, if you are using a state store.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewCentosAmazonCluster

func NewCentosAmazonCluster(name string) *cluster.Cluster

func NewCentosDigitalOceanCluster

func NewCentosDigitalOceanCluster(name string) *cluster.Cluster

NewCentosDigitalOceanCluster creates a basic CentOS DigitalOcean cluster.

func NewUbuntuAmazonCluster

func NewUbuntuAmazonCluster(name string) *cluster.Cluster

NewUbuntuAmazonCluster creates a simple Ubuntu Amazon cluster

func NewUbuntuAzureCluster

func NewUbuntuAzureCluster(name string) *cluster.Cluster

NewUbuntuAzureCluster creates a basic Digitalocean cluster profile, to bootstrap Kubernetes.

func NewUbuntuDigitalOceanCluster

func NewUbuntuDigitalOceanCluster(name string) *cluster.Cluster

NewUbuntuDigitalOceanCluster creates a basic Digitalocean cluster profile, to bootstrap Kubernetes.

func NewUbuntuGoogleComputeCluster

func NewUbuntuGoogleComputeCluster(name string) *cluster.Cluster

NewUbuntuGoogleComputeCluster creates a basic Ubuntu Google Compute cluster.

Types

This section is empty.

Jump to