Documentation
¶
Index ¶
- func NewCentosAmazonCluster(name string) *cluster.Cluster
- func NewCentosDigitalOceanCluster(name string) *cluster.Cluster
- func NewUbuntuAmazonCluster(name string) *cluster.Cluster
- func NewUbuntuAzureCluster(name string) *cluster.Cluster
- func NewUbuntuDigitalOceanCluster(name string) *cluster.Cluster
- func NewUbuntuGoogleComputeCluster(name string) *cluster.Cluster
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewCentosAmazonCluster ¶
func NewCentosDigitalOceanCluster ¶
NewCentosDigitalOceanCluster creates a basic CentOS DigitalOcean cluster.
func NewUbuntuAmazonCluster ¶
NewUbuntuAmazonCluster creates a simple Ubuntu Amazon cluster
func NewUbuntuAzureCluster ¶
NewUbuntuAzureCluster creates a basic Digitalocean cluster profile, to bootstrap Kubernetes.
func NewUbuntuDigitalOceanCluster ¶
NewUbuntuDigitalOceanCluster creates a basic Digitalocean cluster profile, to bootstrap Kubernetes.
func NewUbuntuGoogleComputeCluster ¶
NewUbuntuGoogleComputeCluster creates a basic Ubuntu Google Compute cluster.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.